@@ -15,7 +15,7 @@ var npa = require('npm-package-arg')
 var realizePackageSpecifier = require('realize-package-specifier')
 
 var addLocal = require('./add-local.js')
-var getCacheStat = require('./get-stat.js')
+var correctMkdir = require('../utils/correct-mkdir.js')
 var git = require('../utils/git.js')
 var npm = require('../npm.js')
 var rm = require('../utils/gently-rm.js')
@@ -380,7 +380,7 @@ function checkoutTreeish (from, resolvedURL, resolvedTreeish, tmpdir, cb) {
 }
 
 function getGitDir (cb) {
-  getCacheStat(function (er, stats) {
+  correctMkdir(remotes, function (er, stats) {
     if (er) return cb(er)
 
     // We don't need global templates when cloning. Use an empty directory for
@@ -391,11 +391,7 @@ function getGitDir (cb) {
       // Ensure that both the template and remotes directories have the correct
       // permissions.
       fs.chown(templates, stats.uid, stats.gid, function (er) {
-        if (er) return cb(er)
-
-        fs.chown(remotes, stats.uid, stats.gid, function (er) {
-          cb(er, stats)
-        })
+        cb(er, stats)
       })
     })
   })
